@@ -3,7 +3,7 @@
 use thiserror::Error;
 
 /// Error type for decoding Tor objects from bytes.
-#[derive(Error, Debug, PartialEq, Eq, Clone)]
+#[derive(Error, Debug, Clone)]
 #[non_exhaustive]
 pub enum Error {
     /// Tried to read something, but we didn't find enough bytes.
@@ -24,6 +24,19 @@ pub enum Error {
     ///
     /// We use this one in lieu of calling assert() and expect() and
     /// unwrap() from within parsing code.
-    #[error("internal programming error")]
-    Internal,
+    #[error("bug")]
+    Bug(#[from] tor_error::Bug),
+}
+
+impl PartialEq for Error {
+    fn eq(&self, other: &Self) -> bool {
+        use Error::*;
+        match (self, other) {
+            (Truncated, Truncated) => true,
+            (ExtraneousBytes, ExtraneousBytes) => true,
+            (BadMessage(a), BadMessage(b)) => a == b,
+            // notably, this means that an internal error is equal to nothing, not even itself.
+            (_, _) => false,
+        }
+    }
 }
